@@ -3,7 +3,7 @@ Python bindings to odesk API
 python-odesk version 0.1
 (C) 2010 oDesk
 """
-VERSION = (0, 1, 0, 'final', 0)
+VERSION = (0, 1, 1, 'final', 1)
 
 from datetime import date
 
@@ -400,9 +400,9 @@ class HR2(Namespace):
         '''
         data = {}
         if user_id:
-            data = {'user__reference': user_id}
-        elif team_id:
-            data = {'team__reference': team_id}
+            data['user__reference'] = user_id
+        if team_id:
+            data['team__reference'] = team_id
         data['include_sub_teams'] = sub_teams
         url = 'userroles'
         result = self.get(url, data)
